/**
 * P4
 * http://snarfed.org/space/p4
 *
 * Copyright 2001-2004
 * Ken Ashcraft <kashcraft+p4@gmail.com>
 * Ryan Barrett <p4@ryanb.org>
 * Maulik Shah <p4@maulik.net>
 * Nathan Stoll <nathanstoll+p4@gmail.com>
 *
 * File: server.cpp
 *
 * The mock backend server.
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
 * more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 59 Temple
 * Place, Suite 330, Boston, MA 02111-1307 USA
 */


#include "p4plugin.h"
#include "p4client.h"
#include "p4mockclient.h"

#include <assert.h>
#include <iostream>
using namespace std;

const ushort ksyncer_plugin_id = 2481;


/* recv_msgs
 *
 * Receives incoming data on the given socket and dumps it to stdout. If the
 * connection is closed, recv_msgs returns.
 */
void recv_msgs()
{
  char msg[256];
  uint ret;
  int written;
  bool encrypted;


  while (!(ret = p4_receive(ksyncer_plugin_id, NULL, msg, 256, &written,
                            &encrypted))) {
    if (written == 0)
      break;

    assert(written <= 256);
    msg[written - 1] = '\0';
    cout << msg << endl;
  }

  if (ret > 0)
    cout << "p4_receive error" << endl;
  else if (written == 0)
    cout << "client disconnected" << endl;
}


int main(int argc, char **argv)
{
  ushort port;

  cout << "Enter the port to listen on (1025-65535): ";
  cin >> port;
  assert(port > 1024);
  
  p4_mock_setup(NULL /* address */, port);
  p4_bootstrap();
  recv_msgs();
  p4_quit();

  return 0;
}


